@@ -37,6 +37,7 @@
 extern GirlData *girl;
 extern GList *girl_stations;
 extern GList *girl_listeners;
+extern GList *girl_streams;
 
 extern GtkWidget *girl_app;
 
@@ -137,7 +138,7 @@ void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType
 	gint        out, error;
 	GIOChannel *out_ch, *err_ch;
 	gboolean    ret;
-	
+
 	g_return_if_fail(url != NULL);
 	MSG("%s", url);
 
@@ -228,7 +229,6 @@ void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType
 						NULL,
 						NULL,
 						&err);
-		
 		if( ! ret )
 		{
 			msg = g_strdup_printf(_("Failed to run %s (%i)\n"), command, pid);
@@ -236,21 +236,17 @@ void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType
 			g_free(msg);
 			return;
 		}
-		
 		/* Add watch function to catch termination of the process. This function
 		 * will clean any remnants of process. */
 		g_child_watch_add( pid, (GChildWatchFunc)cb_child_watch, girl);
 
 		/* Install timeout fnction that will move the progress bar */
 		girl->timeout_id = g_timeout_add(100,(GSourceFunc)cb_timeout,girl);
-
 /* #endif */
-		
 /* #if 0 */
 		ret = g_spawn_async_with_pipes( NULL, /* command */ argv, NULL,
 						/* G_SPAWN_DO_NOT_REAP_CHILD */ G_SPAWN_DEFAULT, NULL,
 						NULL, &pid, NULL, &out, &error, NULL );
-		
 		if( ! ret )
 		{
 			msg = g_strdup_printf(_("Failed to run %s (%i)\n"), command, pid);
@@ -258,11 +254,9 @@ void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType
 			g_free(msg);
 			return;
 		}
-		
 		/* Add watch function to catch termination of the process. This function
 		 * will clean any remnants of process. */
 		g_child_watch_add( pid, (GChildWatchFunc)cb_child_watch, girl );
-		
 		/* Create channels that will be used to read girl from pipes. */
 #ifdef G_OS_WIN32
 		out_ch = g_io_channel_win32_new_fd( out );
@@ -271,18 +265,13 @@ void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType
 		out_ch = g_io_channel_unix_new( out );
 		err_ch = g_io_channel_unix_new( err );
 #endif
-		
 		/* Add watches to channels */
 		g_io_add_watch( out_ch, G_IO_IN | G_IO_HUP, (GIOFunc)cb_out_watch, girl );
 		g_io_add_watch( err_ch, G_IO_IN | G_IO_HUP, (GIOFunc)cb_err_watch, girl );
-		
 		/* Install timeout fnction that will move the progress bar */
 		girl->timeout_id = g_timeout_add( 100, (GSourceFunc)cb_timeout, girl );
-		
 /* #endif */
-		
 #if 0
-		
 		if (!g_spawn_command_line_sync(command, stdout, stderr, status, &err)) {
 			msg = g_strdup_printf(_("Failed to open URL: '%s'\n"
 						"Status code: %i\n"
@@ -293,11 +282,9 @@ void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType
 		} else {
 			g_print("Launching %s\n", command);
 		}
-		
 		/* Add watch function to catch termination of the process. This function
 		 * will clean any remnants of process. */
 		g_child_watch_add( pid, (GChildWatchFunc)cb_child_watch, girl );
-		
 #endif
 	}
 }
@@ -310,9 +297,16 @@ void girl_stream_player(GtkWidget * widget, gpointer data)
 		        GIRL_STREAM_PLAYER);
 }
 
-void girl_info_view(GirlStationInfo * info)
+void girl_stream_record(GtkWidget * widget, gpointer data)
 {
+	girl_helper_run(girl->selected_station_uri,
+			girl->selected_station_name,
+			GIRL_STREAM_SHOUTCAST,
+		        GIRL_STREAM_RECORD);
+}
 
+void girl_stream_select(GirlStreamsInfo * info)
+{
 }
 
 static void
